---
layout: page
title: Assessment
has_children: true
nav_order: 4
---

# {{page.title}}

This course provides *formative feedback* throughout the course and defines *pass/fail criteria* and *graded components* for the summative assessment.


## Formative Feedback

Throughout the course, you will provide and receive formative feedback using the same rubrics that will be used for the final, summative assessment.
Each weeks feedback has certain focus points that are usually focussing on recent assignments.

While some rubric items will be *pass/fail*, most rubric items are scored on a basic scale:

- *Insufficient:* Below the required level. This must be addressed as soon as possible and should improve significantly.
- *Sufficient:* Right around the required level, pay attention not to slip into an insufficient.
- *Good:* A solid level that shows that the assignment goals have been well met.
- *Very Good:* A good submission, which exceeds the expectations in some aspects.
- *Excellent:* Great submission that overall exceeds the expectations. Well done!

The goal of the formative feedback is to warn you in time about aspects of your project that are below the expected level.
Formative feedback does not influence the grade, the goal is to inform you about your study progress and to help you understand how we will assess your efforts in the end.

*Please note:* Not improving an insufficient rating before the course ends will be reflected in your grade; it might even affect your ability to pass the course.


## Pass/Fail Criteria

The course defines pass/fail criteria to ensure that students can follow the teamwork phase by checking whether necessary skills have been acquired and feedback has been provided.
Also, the criteria protect teams from unmotivated students that try to capitalize on the work of others.

{: .caution}
Each student needs to pass *all* criteria or they will fail the course, regardless of their overall performance in the other areas of the project.


- Upholding a professional attitude when interacting with peers and staff.
- Constructive participation in the peer review process (All! No repair!)
	- 6x [Peer Review][peer-review] of the assignments (for another team and your own)
	- 2x [Buddycheck][buddycheck] peer evaluation (within the team)
- Actively participating in the team process
	- Visibly contributing to the project throughout all weeks of the project
	- Contributing to all team deadlines and deliverables
	- Receiving a positive evaluation in final Buddycheck review
- Ability to explain lecture contents and defend all aspects of the team project in the oral examination
- Availability of team results for grading (repositories, essay, artifacts)

[peer-review]: {%link assignments/peer-review.md%}
[buddycheck]: {%link assignments/buddycheck.md%}


## Graded components

The grading of our course is based on the following aspects.
Please study the linked rubrics to understand the concrete requirements.
The rubrics are also linked in the relevant assignments.

{:.info}
Most rubric items are written in a cumulative style, i.e., to achieve a "Good", your submission also needs to pass the bar for a "Sufficient".
This applies for all grade steps. 


- **Project (55%):** How well has the project been implemented?
	- [Basic Requirements]({%link assessment/basic-requirements.md%})
	- [Versioning & Releases]({%link assessment/versioning-and-releases.md%})
	- [Containers & Orchestration]({%link assessment/containers-and-orchestration.md%})
	- [Kubernetes & Monitoring]({%link assessment/kubernetes-and-monitoring.md%})
	- [Istio Service Mesh]({%link assessment/istio-service-mesh.md%})
	- [ML Configuration Management]({%link assessment/a4-rubric-ml-config.md%})
	- [ML Testing]({%link assessment/a5-ml-testing.md%})
- **Report (40%):** How well has the project been documented?
	- [Report]({%link assessment/report.md%})
	- [Istio Service Mesh]({%link assessment/istio-service-mesh.md%}) (See *"Continuous Experimentation"* and *"Additional Use Case"*)
- **Presentation & Oral Examination (5%):** Illustrating the features of the created application and checking individually, whether the learning objectives of the course have been reached.
	- [Presentation]({%link assessment/presentation.md%})
- **Individual Adjustment:** The project will receive a team grade. The Buddycheck results will be taken into account to adjust the team grade for individuals from -0.5 to +0.5 to the final grade.


*Please note:* The oral examination is a pass/fail decision and does not influence the grade.
It serves as a measure for fraud prevention and will be used to check individually whether LOs have been reached by asking questions about lecture contents and aspects of the team application.
Students that are unable to answer these questions will fail the course, as defined in the individual pass/fail criteria.

[rubric-process]: {{site.baseurl}}/grading/process
[rubric-product]: {{site.baseurl}}/grading/product
[rubric-hci]: {{site.baseurl}}/grading/heuristic-usability-evaluation
[rubric-pitch]: {{site.baseurl}}/grading/product-pitch


